@@ -14,9 +14,8 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * License along with this program; if not, see
+ * <http://www.gnu.org/licenses/>.
  */
 
 #include "config.h"
@@ -41,7 +40,7 @@ struct _GkmStorePrivate {
 	GHashTable *schemas;
 };
 
-G_DEFINE_TYPE (GkmStore, gkm_store, G_TYPE_OBJECT);
+G_DEFINE_TYPE_WITH_PRIVATE (GkmStore, gkm_store, G_TYPE_OBJECT);
 
 /* -----------------------------------------------------------------------------
  * INTERNAL
@@ -76,7 +75,7 @@ gkm_store_constructor (GType type, guint n_props, GObjectConstructParam *props)
 static void
 gkm_store_init (GkmStore *self)
 {
-	self->pv = G_TYPE_INSTANCE_GET_PRIVATE (self, GKM_TYPE_STORE, GkmStorePrivate);
+	self->pv = gkm_store_get_instance_private (self);
 	self->pv->schemas = g_hash_table_new_full (gkm_util_ulong_hash, gkm_util_ulong_equal,
 	                                           NULL, schema_free);
 }
@@ -133,8 +132,6 @@ gkm_store_class_init (GkmStoreClass *klass)
 	gobject_class->finalize = gkm_store_finalize;
 	gobject_class->set_property = gkm_store_set_property;
 	gobject_class->get_property = gkm_store_get_property;
-
-	g_type_class_add_private (klass, sizeof (GkmStorePrivate));
 }
 
 /* -----------------------------------------------------------------------------
